Calculate Biological Monitoring Working Party (BMWP) prime prime index (Loyola, 2000)
Usage
bmwp_p_p_ind(dataset, store = FALSE, dec_c = ".", verbose = FALSE)
Value
This function returns a list with the following components:
Ibmwp_p_p_n
The numerical BMWP’’ index (Loyola, 2000).
Ibmwp_p_p_c
The BMWP’’ water quality classes (Loyola, 2000).
Arguments
dataset
A data.frame obtained from read_data.
store
A logical value indicating if the user want to store the results in a file.
dec_c
A character used for decimal separator on results file.
verbose
A logical value indicating if progress messages should be given.
Author
Juan Manuel Cabrera and Julieta Capeletti.
Details
The new BMWP’’ is an adaptation of the BMWP (Armitage et al. 1983) for the lotic environments of the Paraná River. This adaptation was based on the observation of the occurrence of the important families in the rivers in the region. Some families were added by ecological equivalence and others by similarity in the level of tolerance to contamination. The scores assigned to the different families were not changed (Loyola, 2000).
References
Armitage PD, Moss D, Wright JF & Furse MT (1983). The performance of a new biological water quality score system based on macroinvertebrates over a wide range of unpolluted running-water sites. tools:::Rd_expr_doi("10.1016/0043-1354(83)90188-4")
#Load example dataexample_data
#Run bmwp_p_p_ind with that example_databmwpp<-bmwp_p_p_ind(example_data)
#Check resultsbmwpp$Ibmwp_p_p_n
bmwpp$Ibmwp_p_p_c