Indicate sensitivity of the assemblage and component species to various types of disturbance.
tol_metrics(dataset, store = FALSE, dec_c = ".", verbose = FALSE)This function returns a data.frame with all the calculated tolerance measures.:
Oligochaeta/Chironomidae.
Oligochaeta with setaform chaetae/Oligochaeta without setaform chaetae.
Tanytarsini/Chironomidae.
Limnodrilus hoffmeisteri/Total density.
Bothrioneurum/Total density.
Tubifex/Total density.
Dero/Total density.
Pristina/Total density.
Chironomus/Total density.
A data.frame obtained from read_data.
A logical value indicating if the user want to store the results in a file.
A character used for decimal separator on results file.
A logical value indicating if progress messages should be given.
Juan Manuel Cabrera and Julieta Capeletti.
Most of the metrics applied in the study of macroinvertebrates use as a key factor the tolerance or intolerance of the different taxa to a certain disturbance, normally organic contamination. The relationship between the number of organisms that are tolerant and intolerant to contamination is a common resource in the metrics used. Further metrics (multimetric indexes) can be derived from a combination of these primary metrics (Prat et al., 2009). The Limnodrilus hoffmeisteri/total density ratio, which was developed by Marchese & Ezcurra de Drago (1999), increases in environments with organic contamination.
Marchese M & Ezcurra de Drago I (1999). Use of benthic macroinvertebrates as organic pollution indicators in lotic environments of the Parana River drainage basin. https://agro.icm.edu.pl/agro/element/bwmeta1.element.agro-article-e981d07b-e469-4460-a7fe-3239650cd089
Prat N, Ríos B, Acosta R & Rieradevall M (2009). Los macroinvertebrados como indicadores de calidad de las aguas. http://www.ub.edu/riosandes/docs/MacroIndLatinAmcompag0908.pdf
read_data
#Load example data
example_data
#Run tol_metrics with that example_data
tolmetrics<-tol_metrics(example_data)
#Check results
tolmetrics
Run the code above in your browser using DataLab