Learn R Programming

metrix (version 1.1.0)

troph_metrics: Trophic metrics

Description

Calculates trophic measures

Usage

troph_metrics(dataset, store = FALSE, dec_c = ".", verbose = FALSE)

Value

This function returns a data.frame with all the calculated trophic measures:

per_pred

% Predator.

per_filt

% Filtering collector.

per_shred

% Shredders.

per_scrap

% Scrapers.

per_gath

% Gathering collector.

n_pred

N° of Predator.

n_filt

N° of Filtering collector.

n_shred

N° of Shredders.

n_scrap

N° of Scrapers.

n_gath

N° of Gathering collector.

Arguments

dataset

A data.frame obtained from read_data.

store

A logical value indicating if the user want to store the results in a file.

dec_c

A character used for decimal separator on results file.

verbose

A logical value indicating if progress messages should be given.

Author

Juan Manuel Cabrera and Julieta Capeletti.

Details

Trophic metrics are surrogates of complex processes such as trophic interaction, production and food source availability. Specialized feeders, such as scrapers, piercers, and shredders, are the more sensitive, and are thought to be well represented in healthy streams. Generalists, such as collectors and filterers, have a broader range of acceptable food materials than specialists, and are thus more tolerant to pollution that might alter availability of certain food (Barbour et al., 1996).

References

Barbour MT, Gerritsen J, Griffith GE, Frydenborg R, McCarron E, White JS & Bastian ML (1996). A Framework for Biological Criteria for Florida Streams Using Benthic Macroinvertebrates. tools:::Rd_expr_doi("10.2307/1467948")

See Also

read_data

Examples

Run this code

#Load example data
example_data

#Run troph_metrics with that example_data
trophmetrics<-troph_metrics(example_data)

#Check results
trophmetrics

Run the code above in your browser using DataLab