Calculates the Indice de Macroinvertebrados en Rios Pampeanos Index
Usage
imrp_ind(dataset, store = FALSE, dec_c = ".", verbose = FALSE)
Value
This function returns a list with the following components:
Imrp_n
The numerical IMRP index (Rodrigues Capítulo 1999).
Imrp_c
The IMRP index water quality class (Rodrigues Capítulo 1999).
Arguments
dataset
A data.frame obtained from read_data.
store
A logical value indicating if the user want to store the results in a file.
dec_c
A character used for decimal separator on results file.
verbose
A logical value indicating if progress messages should be given.
Author
Juan Manuel Cabrera and Julieta Capeletti.
Details
IMRP was created for the rivers of the Pampean plain (Rodrigues Capítulo 1999). This index is based on the sum of ecological values for each taxon. This value is inversely proportional to the degree of tolerance to contamination, varying from 0.1 for highly tolerant taxa to 2.0 for the most sensitive. Identification to family is sufficient to calculate the IMRP score.